@@ -1,11 +1,6 @@
-# -*- coding: utf-8 -*-
-from __future__ import unicode_literals
-
-import pytest
-
-import django
 from django import forms
-from django.template.base import Context, Template
+from django.template.base import Template
+from django.template.context import Context
 
 from crispy_forms.helper import FormHelper
 from crispy_forms.layout import Layout
@@ -17,19 +12,18 @@ def test_list_intersection():
 
 
 def test_list_difference():
-    assert list_difference([3, 1, 2, 3], [4, 1, ]) == [3, 2]
+    assert list_difference([3, 1, 2, 3], [4, 1]) == [3, 2]
 
 
 def test_render_field_with_none_field():
     rendered = render_field(field=None, form=None, form_style=None, context=None)
-    assert rendered == ''
+    assert rendered == ""
+
 
-@pytest.mark.skipif(django.VERSION < (1, 9),
-                    reason="Custom BoundField behavior is was introduced in 1.9.")
 def test_custom_bound_field():
     from django.forms.boundfield import BoundField
 
-    extra = 'xyxyxyxyxyx'
+    extra = "xyxyxyxyxyx"
 
     class CustomBoundField(BoundField):
         @property
@@ -44,11 +38,11 @@ def test_custom_bound_field():
         f = MyCharField()
 
         def __init__(self, *args, **kwargs):
-            super(MyForm, self).__init__(*args, **kwargs)
+            super().__init__(*args, **kwargs)
             self.helper = FormHelper()
-            self.helper.layout = Layout('f')
+            self.helper.layout = Layout("f")
 
     template = Template('{% load crispy_forms_tags %}\n{% crispy form "bootstrap3" %}')
-    rendered = template.render(Context({'form': MyForm(data={'f': 'something'})}))
+    rendered = template.render(Context({"form": MyForm(data={"f": "something"})}))
 
     assert extra in rendered
